<?php
/**
 * Your Inspiration Themes
 *
 * @package WordPress
 * @subpackage Your Inspiration Themes
 * @author Your Inspiration Themes Team <info@yithemes.com>
 *
 * This source file is subject to the GNU GENERAL PUBLIC LICENSE (GPL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://www.gnu.org/licenses/gpl-3.0.txt
 */

/**
 * Class to print fields in the tab Colors -> Buttons
 *
 * @since 1.0.0
 */

class YIT_Submenu_Tabs_Theme_option_Colors_Buttons extends YIT_Submenu_Tabs_Abstract {
    /**
     * Default fields
     *
     * @var array
     * @since 1.0.0
     */
    public $fields;

    /**
     * Merge default fields with theme specific fields using the filter yit_submenu_tabs_theme_option_typography_buttons
     *
     * @param array $fields
     * @since 1.0.0
     */
    public function __construct() {
        $fields = $this->init();
        $this->fields = apply_filters( strtolower( __CLASS__ ), $fields );
    }

    /**
     * Set default values
     *
     * @return array
     * @since 1.0.0
     */
    public function init() {
        return array(

            10 => array(
                'id' => 'background-alt-buttons',
                'type' => 'colorpicker',
                'name' => __( 'Buttons background', 'yit' ),
                'desc' => __( 'Select a background for the buttons of all pages.', 'yit' ),
                'std' => apply_filters( 'yit_background-alt-buttons_std', '#474748' ),
                'style' => apply_filters( 'yit_background-buttons_selectors', array(
                    'selectors' => '.sidebar .widget_search #searchform .button, .sidebar .widget_search_mini #mini-search-submit, .alt-buttons a, .alt-button, .woocommerce ul.products li.product.grid .buttons-list-wrapper a.button, .woocommerce div.product form.cart .button,
.woocommerce a.button, .woocommerce button.button, .woocommerce input.button, .woocommerce #respond input#submit,
.woocommerce #content input.button, .woocommerce-page a.button, .woocommerce-page button.button,
.woocommerce-page input.button, .woocommerce-page #respond input#submit, .woocommerce-page #content input.button,
a.button, button.button, input.button, #respond input#submit, #place_order, .woocommerce .wishlist_table .product-add-to-cart a.add_to_cart.button.alt, .woocommerce .cart-collaterals input[type=submit].button.checkout-button:hover,
#popupWrap .popup .popup-newsletter-section .input-prepend .submit-field, .btn-button,
.contact-form li.submit-button input.sendmail, .sidebar .widget_product_search #searchform #searchsubmit, .yith-wcaf input[type=submit], .yith-wcaf-datepicker button',
                    'properties' => 'background-color'
                ) )
            ),

            20 => array(
                'id' => 'background-alt-buttons-hover',
                'type' => 'colorpicker',
                'name' => __( 'Buttons Background Hover', 'yit' ),
                'desc' => __( 'Select a background hover for the buttons of all pages.', 'yit' ),
                'std' => apply_filters( 'yit_background-alt-buttons-hover_std', '#646465' ),
                'style' => apply_filters( 'yit_background-buttons-hover_selectors', array(
                    'selectors' => '.sidebar .widget_search #searchform .button:hover, .sidebar .widget_search_mini #mini-search-submit:hover ,.alt-buttons a:hover, .alt-button:hover, .woocommerce ul.products li.product.grid .buttons-list-wrapper a.button:hover, .woocommerce div.product form.cart .button:hover,
.woocommerce a.button:hover, .woocommerce button.button:hover, .woocommerce input.button:hover,
.woocommerce #respond input#submit:hover, .woocommerce #content input.button:hover, .woocommerce-page a.button:hover,
.woocommerce-page button.button:hover, .woocommerce-page input.button:hover,
.woocommerce-page #respond input#submit:hover, .woocommerce-page #content input.button:hover,
.woocommerce a.button.alt:hover, .woocommerce button.button.alt:hover, .woocommerce input.button.alt:hover,
.woocommerce #respond input#submit.alt:hover, .woocommerce #content input.button.alt:hover,
.woocommerce-page a.button.alt:hover, .woocommerce-page button.button.alt:hover,
.woocommerce-page input.button.alt:hover, .woocommerce-page #respond input#submit.alt:hover,
.woocommerce-page #content input.button.alt:hover,
#place_order:hover,
a.button:hover, button.button:hover, input.button:hover,
.woocommerce .wishlist_table .product-add-to-cart a.add_to_cart.button.alt:hover,
.woocommerce .cart-collaterals input[type=submit].button.checkout-button,
#popupWrap .popup .popup-newsletter-section .input-prepend .submit-field:hover, .btn-button:hover,
.contact-form li.submit-button input.sendmail:hover, .sidebar .widget_product_search #searchform #searchsubmit:hover, .yith-wcaf input[type=submit]:hover, .yith-wcaf-datepicker button:hover',
                    'properties' => 'background-color'
                ) )
            ),

            30 => array(
                'id' => 'alt-buttons-border-colors',
                'type' => 'colorpicker',
                'name' => __( 'Buttons border color', 'yit' ),
                'desc' => __( 'Select a color for the border buttons of all pages.', 'yit' ),
                'std' => apply_filters( 'yit_alt-buttons-border-colors_std', '#474748' ),
                'style' => apply_filters( 'yit_buttons-border-colors_selectors', array(
                    'selectors' => '.sidebar .widget_search #searchform .button, .sidebar .widget_search_mini #mini-search-submit,.alt-buttons a, .alt-button, .woocommerce ul.products li.product.grid .buttons-list-wrapper a.button, .woocommerce div.product form.cart .button,
.woocommerce a.button, .woocommerce button.button, .woocommerce input.button, .woocommerce #respond input#submit,
.woocommerce #content input.button, .woocommerce-page a.button, .woocommerce-page button.button,
.woocommerce-page input.button, .woocommerce-page #respond input#submit, .woocommerce-page #content input.button,
a.button, button.button, input.button, #respond input#submit, #place_order, .woocommerce .cart-collaterals input[type=submit].button.checkout-button:hover,
#popupWrap .popup .popup-newsletter-section .input-prepend .submit-field, .btn-button,
.contact-form li.submit-button input.sendmail, .sidebar .widget_product_search #searchform #searchsubmit, .yith-wcaf input[type=submit], .yith-wcaf-datepicker button',
                    'properties' => 'border-color'
                ) )
            ),

            40 => array(
                'id' => 'alt-buttons-border-hover-colors',
                'type' => 'colorpicker',
                'name' => __( 'Buttons border hover color', 'yit' ),
                'desc' => __( 'Select a color for the hover border buttons of all pages.', 'yit' ),
                'std' => apply_filters( 'yit_alt-buttons-border-hover-colors_std', '#646465' ),
                'style' => apply_filters( 'yit_buttons-border-hover-colors_selectors', array(
                    'selectors' => '.sidebar .widget_search #searchform .button:hover, .sidebar .widget_search_mini #mini-search-submit:hover,.alt-buttons a:hover, .alt-button:hover, .woocommerce ul.products li.product.grid .buttons-list-wrapper a.button:hover, .woocommerce div.product form.cart .button:hover,
.woocommerce a.button:hover, .woocommerce button.button:hover, .woocommerce input.button:hover,
.woocommerce #respond input#submit:hover, .woocommerce #content input.button:hover, .woocommerce-page a.button:hover,
.woocommerce-page button.button:hover, .woocommerce-page input.button:hover,
.woocommerce-page #respond input#submit:hover, .woocommerce-page #content input.button:hover,
.woocommerce a.button.alt:hover, .woocommerce button.button.alt:hover, .woocommerce input.button.alt:hover,
.woocommerce #respond input#submit.alt:hover, .woocommerce #content input.button.alt:hover,
.woocommerce-page a.button.alt:hover, .woocommerce-page button.button.alt:hover,
.woocommerce-page input.button.alt:hover, .woocommerce-page #respond input#submit.alt:hover,
.woocommerce-page #content input.button.alt:hover,
#place_order:hover,
a.button:hover, button.button:hover, input.button:hover,
.woocommerce .cart-collaterals input[type=submit].button.checkout-button,
#popupWrap .popup .popup-newsletter-section .input-prepend .submit-field:hover, .btn-button:hover,
.contact-form li.submit-button input.sendmail:hover, .sidebar .widget_product_search #searchform #searchsubmit:hover, .yith-wcaf input[type=submit]:hover, .yith-wcaf-datepicker button:hover',
                    'properties' => 'border-color'
                ) )

            ),


            50 => array(
                'type' => 'title',
                'name' => __( 'Alternative Buttons', 'yit' ),
                'desc' => __( 'Used for buttons in services', 'yit' )
            ),

            60 => array(
                'id' => 'background-buttons',
                'type' => 'colorpicker',
                'name' => __( 'Buttons background', 'yit' ),
                'desc' => __( 'Select a background for the buttons of all pages.', 'yit' ),
                'std' => apply_filters( 'yit_background-buttons_std', '#ffffff' ),
                'style' => apply_filters( 'yit_background-buttons_selectors', array(
                    'selectors' => 'div.buttons a',
                    'properties' => 'background-color'
                ) )
            ),

            70 => array(
                'id' => 'background-buttons-hover',
                'type' => 'colorpicker',
                'name' => __( 'Buttons Background Hover', 'yit' ),
                'desc' => __( 'Select a background hover for the buttons of all pages.', 'yit' ),
                'std' => apply_filters( 'yit_background-buttons-hover_std', '#3d3d3e' ),
                'style' => apply_filters( 'yit_background-buttons-hover_selectors', array(
                    'selectors' => 'div.buttons:hover, div.buttons:hover a',
                    'properties' => 'background-color'
                ) )
            ),

            80 => array(
                'id' => 'buttons-border-colors',
                'type' => 'colorpicker',
                'name' => __( 'Buttons border color', 'yit' ),
                'desc' => __( 'Select a color for the border buttons of all pages.', 'yit' ),
                'std' => apply_filters( 'yit_buttons-border-colors_std', '#89898b' ),
                'style' => apply_filters( 'yit_buttons-border-colors_selectors', array(
                    'selectors' => '.buttons a',
                    'properties' => 'border-color'
                ) )
            ),

            90 => array(
                'id' => 'buttons-border-hover-colors',
                'type' => 'colorpicker',
                'name' => __( 'Buttons border hover color', 'yit' ),
                'desc' => __( 'Select a color for the hover border buttons of all pages.', 'yit' ),
                'std' => apply_filters( 'yit_buttons-border-hover-colors_std', '#3d3d3e' ),
                'style' => apply_filters( 'yit_buttons-border-hover-colors_selectors', array(
                    'selectors' => '.buttons a:hover',
                    'properties' => 'border-color'
                ) )

            ),

        );
    }
}