<?php
/**
 * Your Inspiration Themes
 *
 * @package WordPress
 * @subpackage Your Inspiration Themes
 * @author Your Inspiration Themes Team <info@yithemes.com>
 *
 * This source file is subject to the GNU GENERAL PUBLIC LICENSE (GPL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://www.gnu.org/licenses/gpl-3.0.txt
 */

/**
 * Class to print fields in the tab Typography -> General
 *
 * @since 1.0.0
 */

class YIT_Submenu_Tabs_Theme_option_Typography_Buttons extends YIT_Submenu_Tabs_Abstract {
    /**
     * Default fields
     *
     * @var array
     * @since 1.0.0
     */
    public $fields;

    /**
     * Merge default fields with theme specific fields using the filter yit_submenu_tabs_theme_option_typography_buttons
     *
     * @param array $fields
     * @since 1.0.0
     */
    public function __construct() {
        $fields = $this->init();
        $this->fields = apply_filters( strtolower( __CLASS__ ), $fields );
    }

    /**
     * Set default values
     *
     * @return array
     * @since 1.0.0
     */
    public function init() {
        return array(
            10 => array(
                'id'   => 'alt_buttons_text_typography',
                'type' => 'typography',
                'name' => __( 'Buttons Typography', 'yit' ),
                'desc' => __( 'Select the font, color and size for buttons text. ', 'yit' ),
                'min'  => 1,
                'max'  => 18,
                'std'  => apply_filters( 'yit_alt_buttons-text-typography_std', array(
                    'size'   => 11,
                    'unit'   => 'px',
                    'family' => 'Noticia Text',
                    'style'  => 'regular',
                    'color'  => '#ffffff'
                ) ),
                'style' => apply_filters( 'yit_alt_buttons-text-typography_style', array(
                    'selectors' => '.sidebar .widget_search #searchform .button, .sidebar .widget_search_mini #mini-search-submit, .alt-buttons a, .alt-button, .woocommerce ul.products li.product.grid .buttons-list-wrapper a.button, .woocommerce div.product form.cart .button,
.woocommerce a.button, .woocommerce button.button, .woocommerce input.button, .woocommerce input.checkout-button, .woocommerce #respond input#submit, .woocommerce-page input.button.alt,
.woocommerce #content input.button, .woocommerce-page a.button, .woocommerce-page button.button,
.woocommerce-page input.button, .woocommerce-page #respond input#submit, .woocommerce-page #content input.button,
a.button, button.button, input.button, #respond input#submit, #place_order,
.woocommerce-page a.button.alt,
#popupWrap .popup .popup-newsletter-section .input-prepend .submit-field, .btn-button, btn-mini,
.contact-form li.submit-button input.sendmail, .sidebar .widget_product_search #searchform #searchsubmit, .yith-wcaf input[type=submit], .yith-wcaf-datepicker button',
                    'properties' => 'font-size, font-family, color, font-style, font-weight'
                ) )
            ),

            20 => array(
                'id' => 'alt_buttons_text_typography_hover',
                'type' => 'colorpicker',
                'name' => __( 'Buttons color hover', 'yit' ),
                'desc' => __( 'Select a text color hover for the buttons of all pages.', 'yit' ),
                'std' => apply_filters( 'yit_alt_buttons-text-typography-hover_std', '#ffffff' ),
                'style' => apply_filters( 'yit_alt_buttons-text-typography-hover_selectors', array(
                    'selectors' => '.sidebar .widget_search #searchform .button:hover, .sidebar .widget_search_mini #mini-search-submit:hover, .alt-buttons a, .alt-button:hover, .woocommerce ul.products li.product.grid .buttons-list-wrapper a.button:hover, .woocommerce div.product form.cart .button:hover,
.woocommerce a.button:hover, .woocommerce button.button:hover, .woocommerce input.button:hover, .woocommerce input.checkout-button:hover,
.woocommerce #respond input#submit:hover, .woocommerce #content input.button:hover, .woocommerce-page a.button:hover,
.woocommerce-page button.button:hover, .woocommerce-page input.button:hover,
.woocommerce-page #respond input#submit:hover, .woocommerce-page #content input.button:hover,
.woocommerce a.button.alt:hover, .woocommerce button.button.alt:hover, .woocommerce input.button.alt:hover,
.woocommerce #respond input#submit.alt:hover, .woocommerce #content input.button.alt:hover,
.woocommerce-page a.button.alt:hover, .woocommerce-page button.button.alt:hover,
.woocommerce-page input.button.alt:hover, .woocommerce-page #respond input#submit.alt:hover,
.woocommerce-page #content input.button.alt:hover,
#place_order:hover,
a.button:hover, button.button:hover, input.button:hover,
.woocommerce-page a.button.alt:hover,
#popupWrap .popup .popup-newsletter-section .input-prepend .submit-field:hover, .btn-button:hover,
.contact-form li.submit-button input.sendmail:hover, .sidebar .widget_product_search #searchform #searchsubmit:hover, .yith-wcaf input[type=submit], .yith-wcaf-datepicker button:hover',
                    'properties' => 'color'
                ) )
            ),

            30 => array(
                'type' => 'title',
                'name' => __( 'Alternative Buttons', 'yit' ),
                'desc' => __( 'Used for buttons in services', 'yit' )
            ),

            40 => array(
                'id'   => 'buttons_text_typography',
                'type' => 'typography',
                'name' => __( 'Buttons Typography', 'yit' ),
                'desc' => __( 'Select the font, color and size for buttons text. ', 'yit' ),
                'min'  => 1,
                'max'  => 18,
                'std'  => apply_filters( 'yit_buttons-text-typography_std', array(
                    'size'   => 16,
                    'unit'   => 'px',
                    'family' => 'Noticia Text',
                    'style'  => 'regular',
                    'color'  => '#302e2e'
                ) ),
                'style' => apply_filters( 'yit_buttons-text-typography_style', array(
                    'selectors' => 'div.buttons a',
                    'properties' => 'font-size, font-family, color, font-style, font-weight'
                ) )
            ),

            50 => array(
                'id' => 'buttons_text_typography_hover',
                'type' => 'colorpicker',
                'name' => __( 'Buttons color hover', 'yit' ),
                'desc' => __( 'Select a text color hover for the buttons of all pages.', 'yit' ),
                'std' => apply_filters( 'yit_buttons-text-typography-hover_std', '#ffffff' ),
                'style' => apply_filters( 'yit_buttons-text-typography-hover_selectors', array(
                    'selectors' => 'div.buttons:hover, div.buttons:hover a',
                    'properties' => 'color'
                ) )
            ),
        );
    }
}